﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2015 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Drawing;
using HeuristicLab.Common;
using HeuristicLab.Core.Networks;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.Networks.Views.NetworkVisualization {
  [StorableClass]
  public sealed class NodeVisualProperties : VisualProperties, INodeVisualProperties {
    [Storable]
    private Point2D<double> lowerLeft;
    public Point2D<double> LowerLeft {
      get { return lowerLeft; }
      set {
        if (lowerLeft == value) return;
        lowerLeft = value;
        OnChanged();
      }
    }

    [Storable]
    private Point2D<double> upperRight;
    public Point2D<double> UpperRight {
      get { return upperRight; }
      set {
        if (upperRight == value) return;
        upperRight = value;
        OnChanged();
      }
    }

    [Storable]
    private Color brushColor;
    public Color BrushColor {
      get { return brushColor; }
      set {
        if (brushColor == value) return;
        brushColor = value;
        OnChanged();
      }
    }

    [Storable]
    private Color penColor;
    public Color PenColor {
      get { return penColor; }
      set {
        if (penColor == value) return;
        penColor = value;
        OnChanged();
      }
    }

    #region Constructors & Cloning
    [StorableConstructor]
    private NodeVisualProperties(bool deserializing) : base(deserializing) { }
    private NodeVisualProperties(NodeVisualProperties original, Cloner cloner)
      : base(original, cloner) {
      lowerLeft = original.lowerLeft;
      upperRight = original.upperRight;
      brushColor = original.brushColor;
      penColor = original.penColor;
    }

    public NodeVisualProperties() {
      lowerLeft = new Point2D<double>(0.0, 0.0);
      upperRight = new Point2D<double>(200.0, 100.0);
      brushColor = Color.FromArgb(255, 120, 200, 240);
      penColor = Color.Black;
    }

    public override IDeepCloneable Clone(Cloner cloner) {
      return new NodeVisualProperties(this, cloner);
    }
    #endregion
  }
}
